@@ -1,17 +1,10 @@
-import datetime
-import decimal
-import functools
-import hashlib
 import json
-import random
-import string
-import uuid
-from copy import deepcopy
-from typing import Union, Optional, Any, Callable
+import datetime
 
 
-def md5(_str: Union[str, bytes]) -> Optional[str]:
+def md5(_str):
     """ md5 string """
+    import hashlib
     if isinstance(_str, bytes):
         return hashlib.md5(_str).hexdigest()
     elif isinstance(_str, str):
@@ -20,6 +13,7 @@ def md5(_str: Union[str, bytes]) -> Optional[str]:
 
 def rstr(n: int = 32) -> str:  # noqa
     """ random string """
+    import random, string
     return ''.join(random.choices(
         string.digits + string.ascii_lowercase + string.ascii_uppercase,
         k=n
@@ -28,6 +22,7 @@ def rstr(n: int = 32) -> str:  # noqa
 
 def ip_to_int(ip: str):
     """ IP convert to int """
+    import functools
     # 192.168.1.13
     # (((((192 * 256) + 168) * 256) + 1) * 256) + 13
     return functools.reduce(lambda x, y: (x << 8) + y, map(int, ip.split('.')))
@@ -84,6 +79,7 @@ class JSONEncoder(json.JSONEncoder):
         return '{}P{}DT{:02d}H{:02d}M{:02d}{}S'.format(sign, days, hours, minutes, seconds, ms)
 
     def default(self, o):
+        import uuid, decimal
         if isinstance(o, datetime.datetime):
             return o.strftime(self.date_time_f)
         elif isinstance(o, datetime.date):
@@ -99,9 +95,11 @@ class JSONEncoder(json.JSONEncoder):
 
 
 def obj_hook(obj, fmt=None):
+    from copy import deepcopy
+
     time_fmt = [
         '%d/%m/%Y %H:%M%S', '%d/%m/%Y %H:%M%S.%f', '%d/%m/%YT%H:%M%S.%f'
-        '%Y-%m-%d %H:%M:%S', '%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M:%S.%f'
+                                                   '%Y-%m-%d %H:%M:%S', '%Y-%m-%dT%H:%M:%S', '%Y-%m-%dT%H:%M:%S.%f'
     ]
 
     if fmt and isinstance(fmt, list):
